@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemListReader.cpp 2173 2006-12-06 16:12:56Z svn $
+ * $Id: UploadItemListReader.cpp 2388 2007-03-10 11:34:50Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -44,7 +44,7 @@
 #include "Message.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: UploadItemListReader.cpp 2173 2006-12-06 16:12:56Z svn $");
+SOURCE_INFO_ADD("$Id: UploadItemListReader.cpp 2388 2007-03-10 11:34:50Z svn $");
 
 /******************************************************************************
  * public メソッド
@@ -187,7 +187,7 @@ void run_all(apr_pool_t *pool, int argc, const char * const *argv)
         dump_level = 0;
     }
 
-    if (!is_exist(pool, data_dir_path)) {
+    if (!File::is_exist(pool, data_dir_path)) {
         THROW(MESSAGE_DATA_DIR_NOT_FOUND);
     }
 
