@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: uploader_handler.cpp 2384 2007-02-14 15:15:33Z svn $
+ * $Id: uploader_handler.cpp 2384M 2007-03-24 14:29:32Z (ローカル) $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -56,7 +56,7 @@
 #include "SourceInfo.h"
 
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: uploader_handler.cpp 2384 2007-02-14 15:15:33Z svn $");
+SOURCE_INFO_ADD("$Id: uploader_handler.cpp 2384M 2007-03-24 14:29:32Z (ローカル) $");
 #endif
 
 #define IS_REQUEST_COMMAND(arg, command)                        \
@@ -647,7 +647,6 @@ static int download(typename Response::Handle *r, UploaderConfig *config,
         UploadItem *uitem;
         const char *download_pass;
         apr_file_t *item_file;
-        const char *file_name;
         const char *open_mode;
         const char *dispos_encoding;
 
@@ -693,7 +692,14 @@ static int download(typename Response::Handle *r, UploaderConfig *config,
         }
 
         try {
+#ifdef RESPONSE_TYPE_APACHE
+            r->filename = const_cast<char *>(file_name);
+            r->finfo.filetype = APR_REG;
+            Response::set_content_type(r);
+#else
             Response::set_content_type(r, uitem->get_file_mime());
+#endif
+
 #ifndef DEBUG
             Response::set_modified_time(r, uitem->get_mtime());
             Response::set_last_modified(r, uitem->get_mtime());
